==> golbikiw-0.2.tar.gz: golbikiw/entries.rb <==
# (c) 2004 Andreas Krennmair
# $Id: entries.rb,v 1.5 2004/03/27 23:47:50 ak Exp $

class Entry

  def initialize(file)
    begin
      entry_file = File.new(file)
      i = 0
      line0 = nil
      lines = []
      entry_file.each_line do |line|
        if i == 0 then
          line0 = line
        else
          lines << line
        end
        i += 1
      end
      fields = line0.split(/ /)
      @categories = fields[0].split(/,/)
      fields.shift
      line0 = fields.join(" ")
      @subject = line0
      @body = lines.join("")
    rescue
    end
    @filename = file
  end

  def get_subject
    @subject
  end

  def get_body
    @body
  end

  def set_subject(s)
    @subject = s
  end

  def set_body(b)
    @body = b
  end

  def get_filename
    @filename
  end

  def get_time
    x = @filename.split("/")
    fn = x[x.size-1]
    year = fn[0..3]
    month = fn[4..5]
    day = fn[6..7]
    hour = fn[9..10]
    min = fn[11..12]
    sec = fn[13..14]
    return "#{year}-#{month}-#{day} #{hour}:#{min}:#{sec}"
  end

  def set_filename(f)
    @filename = f
  end

  def get_categories
    @categories
  end

  def set_categories(a)
    @categories = a
  end

  def write
    begin
      f = File.new(@filename,"w+")
      line0 = @categories.join(",") + " " + @subject + "\n"
      f.write(line0)
      @body.each do |line|
        f.write(line)
      end
      f.close
    rescue
      $stderr.puts "Entry#write: unable to write to #{@filename}: #{$!}"
    end
  end

end

class EntryManager
  
  def initialize(path)
    @path = path
    @filenames = []
    @entries = []
    begin
      Dir.new(@path).each do |file|
        if file =~ /^[0-9]{8}-[0-9]{6}-/ then
          @filenames << file
        end
      end
    rescue
      $stderr.puts "EntryManager#initialize: unable to open #{@path}"
    end
    @filenames = @filenames.sort.reverse
    @filenames.each do |f|
      @entries << Entry.new(@path + "/" + f)
    end
  end

  def get_filenames
    @filenames
  end

  def get_entries
    @entries
  end

  def get_matching(pattern)
    x = []
    @filenames.each_index do |i|
      if @filenames[i] =~ pattern then
        x << @entries[i]
      end
    end
    x
  end

  def EntryManager.wiki_name(x)
    y = x.gsub(/[^ a-zA-Z]/,"");
    foo = y.split(" ")
    foo.each_index do |i|
      foo[i][0..0] = foo[i][0..0].capitalize
    end
    wikiword = foo.join("")
    if foo.size == 1 then
      mid = wikiword.length / 2
      wikiword[mid..mid] = wikiword[mid..mid].capitalize
    end
    return wikiword
  end

  def EntryManager.link_wiki_names(s)
    s.gsub(/([A-Z][a-z]+([A-Z][a-z]+){1,})/,'<a href="index.cgi?wiki=\1">\1</a>')
  end

end

==> golbikiw-0.3.tar.gz: golbikiw/entries.rb <==
# (c) 2004 Andreas Krennmair
# $Id: entries.rb,v 1.8 2004/03/28 17:02:08 ak Exp $

require 'config.rb'

class Entry

  def initialize(file)
    begin
      entry_file = File.new($conf['postdir'] + "/" + file)
      i = 0
      line0 = nil
      lines = []
      entry_file.each_line do |line|
        if i == 0 then
          line0 = line
        else
          lines << line
        end
        i += 1
      end
      fields = line0.split(/ /)
      @categories = fields[0].split(/,/)
      fields.shift
      line0 = fields.join(" ")
      @subject = line0
      @body = lines.join("")
    rescue
    end
    x = file.split("/")
    @filename = x[x.size-1]
  end

  def get_subject
    @subject
  end

  def get_body
    @body
  end

  def set_subject(s)
    @subject = s
  end

  def belongs_to_group(g)
    @categories.each do |h|
      if h.to_i == g.to_i then
        return true
      end
    end
    return false
  end

  def set_body(b)
    @body = b
  end

  def get_filename
    @filename
  end

  def get_time
    x = @filename.split("/")
    fn = x[x.size-1]
    year = fn[0..3]
    month = fn[4..5]
    day = fn[6..7]
    hour = fn[9..10]
    min = fn[11..12]
    sec = fn[13..14]
    return "#{year}-#{month}-#{day} #{hour}:#{min}:#{sec}"
  end

  def get_yearmonth
    x = @filename.split("/")
    fn = x[x.size-1]
    fn[0..5]
  end

  def set_filename(f)
    @filename = f
  end

  def get_categories
    @categories
  end

  def set_categories(a)
    @categories = a
  end

  def write
    begin
      f = File.new($conf['postdir'] + "/" + @filename,"w+")
      line0 = @categories.join(",") + " " + @subject + "\n"
      f.write(line0)
      @body.each do |line|
        f.write(line)
      end
      f.close
    rescue
      $stderr.puts "Entry#write: unable to write to #{@filename}: #{$!}"
    end
  end

end

class EntryManager
  
  def initialize(path)
    @path = path
    @filenames = []
    @entries = []
    begin
      Dir.new(@path).each do |file|
        if file =~ /^[0-9]{8}-[0-9]{6}-/ then
          @filenames << file
        end
      end
    rescue
      $stderr.puts "EntryManager#initialize: unable to open #{@path}"
    end
    @filenames = @filenames.sort.reverse
    @filenames.each do |f|
      @entries << Entry.new(f)
    end
  end

  def get_filenames
    @filenames
  end

  def get_entries
    @entries
  end

  def get_matching(pattern)
    x = []
    @filenames.each_index do |i|
      if @filenames[i] =~ pattern then
        x << @entries[i]
      end
    end
    x
  end

  def EntryManager.wiki_name(x)
    y = x.gsub(/[^ a-zA-Z]/,"");
    foo = y.split(" ")
    foo.each_index do |i|
      foo[i][0..0] = foo[i][0..0].capitalize
    end
    wikiword = foo.join("")
    if foo.size == 1 then
      mid = wikiword.length / 2
      wikiword[mid..mid] = wikiword[mid..mid].capitalize
    end
    return wikiword
  end

  def EntryManager.link_wiki_names(s)
    s.gsub(/([A-Z][a-z]+([A-Z][a-z]+){1,})/,'<a href="index.cgi?wiki=\1">\1</a>')
  end

end
